@@ -54,6 +54,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 01/05/2001       Remco de Boer   Version including full documentation completed
 07/05/2001       Jelle Kok        HeteroPlayerSettings class and dExtraStamina
 08/05/2001       Remco de Boer   Documentation updated
+22/11/2008       Mahdi Nami Damirchi   Settings for server version 13.x added
 </pre>
 */
 
@@ -80,7 +81,26 @@ private:
   // all the parameters available in server.conf
   // NOTE: names in server.conf corresponding with member variables
   //       are listed between doxygen-tags to enable quick searching
+//-------------------------------server13------------------------------
+    double stamina_capacity ;
+    double max_dash_angle ;
+    double min_dash_angle ;
+    double dash_angle_step ;
+    double side_dash_rate ;
+    double back_dash_rate ;
+    double max_dash_power ;
+    double min_dash_power ;
+//------------------------------------------------------------------------
 
+//-------------------------------server12------------------------------
+    double max_tackle_power ;
+    double max_back_tackle_power ;
+    double player_speed_max_min ;
+    int max_monitors ;
+    bool allow_mult_default_type ;
+    int synch_see_offset ;
+    int extra_half_time;
+//------------------------------------------------------------------------
   // goal-related parameters
   double dGoalWidth;        /*!< goal_width: the width of the goal           */
 
@@ -376,12 +396,19 @@ public:
   bool readValues( const char *strFilename, const char *Separator      );
 
   // set- and get methods for private member variables
-
+  bool   setSynchSeeOffset             ( int d       );
+  int    getSynchSeeOffset             (             ) const;
+  bool   setMaxMonitors                ( int d       );
+  int    getMaxMonitors                (             ) const;
+  bool   setAllowMultDefaultType       ( bool d      );
+  bool   getAllowMultDefaultType       (             ) const;
   // set- and get methods for goal-related parameters
   bool   setGoalWidth                  ( double d    );
   double getGoalWidth                  (             ) const;
 
   // set- and get methods for player-related parameters
+  bool   setPlayerSpeedMaxMin          ( double d    );
+  double getPlayerSpeedMaxMin          (             ) const;
   bool   setPlayerSize                 ( double d    );
   double getPlayerSize                 (             ) const;
   bool   setPlayerDecay                ( double d    );
@@ -396,6 +423,8 @@ public:
   double getPlayerAccelMax             (             ) const;
 
   // set- and get methods for stamina-related parameters
+  bool   setStaminaCapacity	       ( double d    );
+  double getStaminaCapacity	       (	     ) const;
   bool   setStaminaMax                 ( double d    );
   double getStaminaMax                 (             ) const;
   bool   setStaminaIncMax              ( double d    );
@@ -470,6 +499,20 @@ public:
   bool   getWindRandom                 (             ) const;
 
   // set- and get methods for parameters related to 'dash' and 'kick' commands
+  bool   setMaxDashAngle               ( double d    );
+  double getMaxDashAngle	       (	     ) const;
+  bool   setMinDashAngle               ( double d    );
+  double getMinDashAngle	       (	     ) const;
+  bool   setDashAngleStep              ( double d    );
+  double getDashAngleStep 	       (	     ) const;
+  bool   setSideDashRate               ( double d    );
+  double getSideDashRate 	       (	     ) const;
+  bool   setBackDashRate               ( double d    );
+  double getBackDashRate 	       (	     ) const;
+  bool   setMaxDashPower               ( double d    );
+  double getMaxDashPower	       (	     ) const;
+  bool   setMinDashPower               ( double d    );
+  double getMinDashPower	       (	     ) const;
   bool   setKickableMargin             ( double d    );
   double getKickableMargin             (             ) const;
   bool   setCkickMargin                ( double d    );
@@ -543,6 +586,8 @@ public:
   int  getSendViStep                   (             ) const;
 
   // set- and get methods for time-related parameters
+  bool   setExtraHalfTime              ( int    i    )      ;
+  int    getExtraHalfTime              (             ) const;
   bool   setSimulatorStep              ( int    i    )      ;
   int    getSimulatorStep              (             ) const;
   bool   setSendStep                   ( int    i    )      ;
@@ -641,6 +686,10 @@ public:
   bool   getPenAllowMultKicks          (             ) const;
 
   // tackle parameters
+  bool   setMaxTacklePower             ( double d    )      ;
+  double getMaxTacklePower             (             ) const;
+  bool   setMaxBackTacklePower         ( double d    )      ;
+  double getMaxBackTacklePower         (             ) const;
   bool   setTackleDist                 ( double d    )      ;
   double getTackleDist                 (             ) const;
   bool   setTackleBackDist             ( double d    )      ;
