@@ -28,29 +28,25 @@ OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-/*! \file SoccerTypes.h
+/*! \file WorldModel.h
 <pre>
-<b>File:</b>          SenseHandler.h
+<b>File:</b>          WorldModel.h
 <b>Project:</b>       Robocup Soccer Simulation Team: UvA Trilearn
 <b>Authors:</b>       Jelle Kok
-<b>Created:</b>       28/11/2000
+<b>Created:</b>       12/02/2001
 <b>Last Revision:</b> $ID$
-<b>Contents:</b>      This file contains the different enumerations and
-               constants that are important in the Soccer Server.
-               Furthermore it contains the class SoccerCommand which is
-               used to denote the different possible soccer commands and
-               the class SoccerTypes that contains all kind of static
-               methods to translate text strings that are received from
-               the server into the soccer types (=enumerations) that
-               are defined here. Finally it contains the Time class which
-               holds a two-tuple that represents the time in the soccer server.
+<b>Contents:</b>      class declarations of WorldModel. This class contains
+               methods that give information about the current and future
+               state of the world (soccer field).
 <hr size=2>
 <h2><b>Changes</b></h2>
 <b>Date</b>             <b>Author</b>          <b>Comment</b>
-28/11/2000       Jelle Kok       Initial version created
+12/02/2001       Jelle Kok             Initial version created
+22/11/2008       Mahdi Nami Damirchi   update for server 13.1
 </pre>
 */
 
+
 #ifndef _SOCCERTYPES_
 #define _SOCCERTYPES_
 
@@ -65,7 +61,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 #define MAX_TEAMMATES          11       /*!< Maximum number of teammates     */
 #define MAX_OPPONENTS          11       /*!< Maximum number of opponents     */
-#define MAX_HETERO_PLAYERS      7       /*!< Maximum number of hetero players*/
+#define MAX_HETERO_PLAYERS      18       /*!< Maximum number of hetero players*/
 #define MAX_MSG              4096       /*!< maximum message size from server*/
 #define MAX_SAY_MSG            10       /*!< maximum size of say message     */
 #define MAX_TEAM_NAME_LENGTH   64       /*!< maximum length of teamname      */
@@ -343,7 +339,8 @@ enum CommandT {
   CMD_ATTENTIONTO,  /*!< pay attention to specific player   */
   CMD_TACKLE,       /*!< tackle in current body direction   */
   CMD_POINTTO,      /*!< point arm towards a point on field */
-  CMD_MAX_COMMANDS  /*!< maximum number of commands         */
+  CMD_MAX_COMMANDS, /*!< maximum number of commands         */
+  CMD_Synch_See     /*!<synch_see command*/
 } ;
 
 /*!The PlayerT enumeration contains the different playertypes that are defined
@@ -593,7 +590,7 @@ class SoccerCommand
   bool  makeAttentionToCommand ( char *str );
   bool  makeTackleCommand      ( char *str );
   bool  makePointToCommand     ( char *str );
-
+  bool  makeSynchSeeToCommand  ( char *str );
 public:
 
   // different variables that are used by the different possible commands
