@@ -28,23 +28,25 @@ OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
-/*! \file WorldModel.cpp
+/*! \file WorldModel.h
 <pre>
-<b>File:</b>          WorldModel.cpp
+<b>File:</b>          WorldModel.h
 <b>Project:</b>       Robocup Soccer Simulation Team: UvA Trilearn
 <b>Authors:</b>       Jelle Kok
 <b>Created:</b>       12/02/2001
 <b>Last Revision:</b> $ID$
-<b>Contents:</b>      class definitions of WorldModel. This class contains
-               the methods of the WorldModel that process the incoming
-               information and analyze the current state of the world.
+<b>Contents:</b>      class declarations of WorldModel. This class contains
+               methods that give information about the current and future
+               state of the world (soccer field).
 <hr size=2>
 <h2><b>Changes</b></h2>
 <b>Date</b>             <b>Author</b>          <b>Comment</b>
-12/02/2001       Jelle Kok       Initial version created
+12/02/2001       Jelle Kok             Initial version created
+22/11/2008       Mahdi Nami Damirchi   update for server 13.1
 </pre>
 */
 
+
 #include<stdio.h>    // needed for printf
 #include<errno.h>    // needed for ETIMEDOUT
 #ifdef WIN32
@@ -1738,6 +1740,13 @@ SoccerCommand WorldModel::getChangeViewCommand( )
   return m_changeViewCommand;
 }
 
+  SoccerCommand   WorldModel::SynchSee                (                                  )
+{
+ SoccerCommand soc;
+soc.commandType=CMD_Synch_See;
+ return soc;
+}
+
 /*! This method returns the side the penalty kick is taken. */
 SideT WorldModel::getSidePenalty( )
 {
