@@ -41,7 +41,8 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 <hr size=2>
 <h2><b>Changes</b></h2>
 <b>Date</b>             <b>Author</b>          <b>Comment</b>
-12/02/2001       Jelle Kok       Initial version created
+12/02/2001       Jelle Kok            Initial version created
+22/11/2008       Mahdi Nami Damirchi  update for server 13.1
 </pre>
 */
 
@@ -229,6 +230,7 @@ private:
   // upcoming view angle/quality
   SoccerCommand m_changeViewCommand;    /*!< last sent change_view command   */
   
+
   // side of penalty shootout
   SideT         m_sidePenalty;
 
@@ -445,7 +447,7 @@ public:
 
   SideT         getSidePenalty             (                                 );
   bool          setSidePenalty             ( SideT          side             );
-
+  SoccerCommand   SynchSee                (                                  );
   ////////////////////////// UPDATE METHODS (WorldModelUpdate.C)///////////////
 
   // processing new information about the objects (filling World Model).
